==> kotlin-reflect-0.12.1230-sources.jar: kotlin/reflect/jvm/internal/impl/load/java/descriptors/SamConstructorDescriptor.kt <==
/*
 * Copyright 2010-2015 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package kotlin.reflect.jvm.internal.impl.load.java.descriptors

import kotlin.reflect.jvm.internal.impl.descriptors.impl.SimpleFunctionDescriptorImpl
import kotlin.reflect.jvm.internal.impl.descriptors.CallableMemberDescriptor
import kotlin.reflect.jvm.internal.impl.descriptors.DeclarationDescriptor
import kotlin.reflect.jvm.internal.impl.resolve.scopes.DescriptorKindExclude

public class SamConstructorDescriptor(
        containingDeclaration: DeclarationDescriptor,
        samInterface: JavaClassDescriptor
) : SimpleFunctionDescriptorImpl(
        containingDeclaration,
        null,
        samInterface.getAnnotations(),
        samInterface.getName(),
        CallableMemberDescriptor.Kind.SYNTHESIZED,
        samInterface.getSource()
)

public object SamConstructorDescriptorKindExclude : DescriptorKindExclude {
    override fun matches(descriptor: DeclarationDescriptor) = descriptor is SamConstructorDescriptor
}

==> kotlin-reflect-0.14.449-sources.jar: kotlin/reflect/jvm/internal/impl/load/java/descriptors/SamConstructorDescriptor.kt <==
/*
 * Copyright 2010-2015 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package kotlin.reflect.jvm.internal.impl.load.java.descriptors

import kotlin.reflect.jvm.internal.impl.descriptors.impl.SimpleFunctionDescriptorImpl
import kotlin.reflect.jvm.internal.impl.descriptors.CallableMemberDescriptor
import kotlin.reflect.jvm.internal.impl.descriptors.DeclarationDescriptor
import kotlin.reflect.jvm.internal.impl.resolve.scopes.DescriptorKindExclude

public class SamConstructorDescriptor(
        containingDeclaration: DeclarationDescriptor,
        samInterface: JavaClassDescriptor
) : SimpleFunctionDescriptorImpl(
        containingDeclaration,
        null,
        samInterface.getAnnotations(),
        samInterface.getName(),
        CallableMemberDescriptor.Kind.SYNTHESIZED,
        samInterface.getSource()
)

public object SamConstructorDescriptorKindExclude : DescriptorKindExclude {
    override fun excludes(descriptor: DeclarationDescriptor) = descriptor is SamConstructorDescriptor

    override val fullyExcludedDescriptorKinds: Int get() = 0
}
